Authors
=======

For the time being, this project is authored by

 - Robert Labudda (https://github.com/vonshednob)


Contributers
============

Thanks goes to these individuals for their contribution:

 - Sander Voerman (https://github.com/sandervoerman)
 - Markus Katharina Brechtel (https://github.com/chaotika)
